@@ -1,7 +1,8 @@
 """AFQ-Insight is a Python library for statistical learning of tractometry data."""
 from . import datasets  # noqa
 from . import utils  # noqa
+from .cross_validate import *  # noqa
 from .datasets import *  # noqa
-from .insight import *  # noqa
+from .pipeline import *  # noqa
 from .transform import *  # noqa
 from ._version import version as __version__  # noqa
